==> rest-connect-1.10.2-sources.jar: org/mule/connectivity/restconnect/internal/modelGeneration/ramlParser/RamlParserOperationGenerator.java <==
package org.mule.connectivity.restconnect.internal.modelGeneration.ramlParser;

import org.mule.connectivity.restconnect.internal.model.HTTPMethod;
import org.mule.connectivity.restconnect.internal.model.operation.Operation;
import org.mule.connectivity.restconnect.internal.model.operation.OperationBuilder;
import org.mule.connectivity.restconnect.internal.model.parameter.Parameter;
import org.mule.connectivity.restconnect.internal.model.parameter.ParameterType;
import org.mule.connectivity.restconnect.internal.model.security.APISecurityScheme;
import org.mule.connectivity.restconnect.internal.modelGeneration.JsonSchemaPool;
import org.raml.v2.api.model.v10.api.Api;
import org.raml.v2.api.model.v10.methods.Method;
import org.raml.v2.api.model.v10.resources.Resource;

import java.util.ArrayList;
import java.util.List;

import static org.mule.connectivity.restconnect.internal.modelGeneration.ramlParser.security.RamlParserSecuritySchemeFactory.getOperationSecuritySchemes;
import static org.mule.connectivity.restconnect.internal.modelGeneration.ramlParser.util.RamlParserUtils.*;

public class RamlParserOperationGenerator {

    public static Operation generateOperation(Api api, Method method, JsonSchemaPool jsonSchemaPool) throws Exception {

        RamlParserTypeDefinitionFactory typeDefinitionFactory = new RamlParserTypeDefinitionFactory(method, jsonSchemaPool);

        Operation operation = new OperationBuilder()
                .withFriendlyName(getMethodDisplayName(method))
                .withAnnotatedDisplayName(getAnnotatedOperationName(method))
                .withCanonicalName(getCanonicalOperationName(method, getMethodDisplayName(method)))
                .withDescription(getMethodDescription(method))
                .withHttpMethod(HTTPMethod.fromString(method.method()))
                .withUri(method.resource().resourcePath())
                .withUriParams(buildUriParams(method, jsonSchemaPool))
                .withQueryParams(buildQueryParams(method, jsonSchemaPool))
                .withHeaders(buildHeaders(method, jsonSchemaPool))
                .withInputMetadata(typeDefinitionFactory.constructInputMetadata())
                .withOutputMetadata(typeDefinitionFactory.constructOutputMetadata())
                .withSecuritySchemes(buildSecuritySchemes(api, method, jsonSchemaPool))
                .withUserSelectedSecuritySchemes(isGenerateUserSelectedSecuritySchemes(method, api))
                .build();

        return operation;
    }

    private static List<APISecurityScheme> buildSecuritySchemes(Api api, Method method, JsonSchemaPool jsonSchemaPool) throws Exception {
        return getOperationSecuritySchemes(api, method, jsonSchemaPool);
    }

    private static List<Parameter> buildQueryParams(Method method, JsonSchemaPool jsonSchemaPool) throws Exception {
        return getParameterList(method.queryParameters(), ParameterType.QUERY, jsonSchemaPool);
    }

    private static List<Parameter> buildUriParams(Method method, JsonSchemaPool jsonSchemaPool) throws Exception {
        List<Parameter> uriParameters = new ArrayList<>();

        // Due to RESTC-34, this is done recursively to the top.
        Resource resource = method.resource();

        while(resource != null) {

            for(Parameter uriParam : getParameterList(resource.uriParameters(), ParameterType.URI, jsonSchemaPool)){
                if(uriParameters.stream().noneMatch(y -> y.getExternalName().equalsIgnoreCase(uriParam.getExternalName()))){
                    uriParameters.add(0, uriParam);
                }
            }

            resource = resource.parentResource();
        }

        return uriParameters;
    }

    private static List<Parameter> buildHeaders(Method method, JsonSchemaPool jsonSchemaPool) throws Exception {
        return getParameterList(method.headers(), ParameterType.HEADER, jsonSchemaPool);
    }

}

==> rest-connect-1.11.4-sources.jar: org/mule/connectivity/restconnect/internal/modelGeneration/ramlParser/RamlParserOperationGenerator.java <==
package org.mule.connectivity.restconnect.internal.modelGeneration.ramlParser;

import org.mule.connectivity.restconnect.internal.model.HTTPMethod;
import org.mule.connectivity.restconnect.internal.model.operation.Operation;
import org.mule.connectivity.restconnect.internal.model.operation.OperationBuilder;
import org.mule.connectivity.restconnect.internal.model.parameter.Parameter;
import org.mule.connectivity.restconnect.internal.model.parameter.ParameterType;
import org.mule.connectivity.restconnect.internal.model.security.APISecurityScheme;
import org.mule.connectivity.restconnect.internal.modelGeneration.JsonSchemaPool;

import org.apache.commons.lang3.StringUtils;
import org.raml.v2.api.model.v10.api.Api;
import org.raml.v2.api.model.v10.methods.Method;
import org.raml.v2.api.model.v10.resources.Resource;

import java.util.ArrayList;
import java.util.List;

import static org.mule.connectivity.restconnect.internal.modelGeneration.ramlParser.security.RamlParserSecuritySchemeFactory.getOperationSecuritySchemes;
import static org.mule.connectivity.restconnect.internal.modelGeneration.ramlParser.util.RamlParserUtils.*;

public class RamlParserOperationGenerator {

    public static Operation generateOperation(Api api, Method method, JsonSchemaPool jsonSchemaPool) throws Exception {

        RamlParserTypeDefinitionFactory typeDefinitionFactory = new RamlParserTypeDefinitionFactory(method, jsonSchemaPool);

        String friendlyName = getMethodDisplayName(method);
        String annotatedName = getAnnotatedOperationName(method);

        Operation operation = new OperationBuilder()
                .withFriendlyName(friendlyName)
                .withAnnotatedDisplayName(StringUtils.isNotBlank(annotatedName) ? annotatedName : friendlyName)
                .withCanonicalName(getCanonicalOperationName(method, getMethodDisplayName(method)))
                .withDescription(getMethodDescription(method))
                .withHttpMethod(HTTPMethod.fromString(method.method()))
                .withUri(method.resource().resourcePath())
                .withUriParams(buildUriParams(method, jsonSchemaPool))
                .withQueryParams(buildQueryParams(method, jsonSchemaPool))
                .withHeaders(buildHeaders(method, jsonSchemaPool))
                .withInputMetadata(typeDefinitionFactory.constructInputMetadata())
                .withOutputMetadata(typeDefinitionFactory.constructOutputMetadata())
                .withSecuritySchemes(buildSecuritySchemes(api, method, jsonSchemaPool))
                .withUserSelectedSecuritySchemes(isGenerateUserSelectedSecuritySchemes(method, api))
                .build();

        return operation;
    }

    private static List<APISecurityScheme> buildSecuritySchemes(Api api, Method method, JsonSchemaPool jsonSchemaPool) throws Exception {
        return getOperationSecuritySchemes(api, method, jsonSchemaPool);
    }

    private static List<Parameter> buildQueryParams(Method method, JsonSchemaPool jsonSchemaPool) throws Exception {
        return getParameterList(method.queryParameters(), ParameterType.QUERY, jsonSchemaPool);
    }

    private static List<Parameter> buildUriParams(Method method, JsonSchemaPool jsonSchemaPool) throws Exception {
        List<Parameter> uriParameters = new ArrayList<>();

        // Due to RESTC-34, this is done recursively to the top.
        Resource resource = method.resource();

        while(resource != null) {

            for(Parameter uriParam : getParameterList(resource.uriParameters(), ParameterType.URI, jsonSchemaPool)){
                if(uriParameters.stream().noneMatch(y -> y.getExternalName().equalsIgnoreCase(uriParam.getExternalName()))){
                    uriParameters.add(0, uriParam);
                }
            }

            resource = resource.parentResource();
        }

        return uriParameters;
    }

    private static List<Parameter> buildHeaders(Method method, JsonSchemaPool jsonSchemaPool) throws Exception {
        return getParameterList(method.headers(), ParameterType.HEADER, jsonSchemaPool);
    }

}
